@@ -3,7 +3,7 @@
 from __future__ import absolute_import, unicode_literals
 
 __author__  = 'Jefurry <jefurry@qq.com>'
-__version__ = '0.1.0'
+__version__ = '0.1.1'
 
 import traceback
 from sqlbuilder import smartsql as sb
@@ -264,17 +264,23 @@ if __name__ == '__main__':
     #print a.qs.where(sb.F.id==2).delete()
     a.delete(a.qs.where(sb.F.id>260).delete())
     print '---------------------------------------'
-    res = a.all(a.qs.where(sb.F.id>1).select('*'))
+    res = a.all(a.qs.where(sb.F.id==1).select('*'))
     print res.id, res.name
     for row in res:
         print row.name, row.id, '@===@'
     print "raw: ", res.raw
+    res2 = a.all(a.qs.where(sb.F.id==2).select('*'))
+    print "+++++++++++++++++++++++++++++++++++++++++++++++"
+    print ".....", (res + res2).raw, "...."
+    print "+++++++++++++++++++++++++++++++++++++++++++++++"
     print '---------------------------------------'
     res = a.first(a.qs.select('*'))
     print res.id, res.name
     for k, v in res:
         print k, v, '*===*'
     print "raw: ", res.raw
+    print "????", (res + res).raw, "????"
+    print "$$$$", result.Result.fromRowResult(res).raw, "$$$$"
     print '---------------------------------------'
     del a
     #print sb.QS(getattr(sb.T, 'user_98')).where((sb.F.status == 1) & (sb.F.a == 'go')).delete()
